<?php  
/**
 * 
 */
class NtzCrmPostPermission  { 
	public static function add_shortcodes(){
		add_shortcode('ntzcrm_icon', array(__CLASS__, 'ntzcrmShortcode'));  
		add_shortcode('ntzcrm_login', array(__CLASS__, 'ntzcrmLogin'));
		add_shortcode('ntzcrm_publications', array(__CLASS__, 'ntzcrmPublications'));
		if (get_option('ntzcrm_opt_default_navlinks') != false && get_option('ntzcrm_opt_default_navlinks') != "") {
			add_filter( 'wp_nav_menu_items', array( __CLASS__, 'ntzcrmNavMenuItems'));
		}
	}
	public static function includeCssJs(){
		add_action( 'admin_init',array(__CLASS__,'ntzcrm_include_css'));
		add_action( 'in_admin_footer',array(__CLASS__,'ntzcrm_include_js')); 
		add_action( 'wp_footer',array(__CLASS__,'ntzcrm_front_include_js')); 
		add_action( 'wp_head',array(__CLASS__,'ntzcrm_include_fronted_css'));
	}

	public static function checkPermission(){ 
		add_action( 'wp_head', array(__CLASS__, '_checkPermission') );
	}

	
	/*
	 * @Function: ntzcrmDefaultNavArgs
	 * To manage Membership Login, Logout & Publication Nav 
	 * Add Members Login, logout & Dashboard Navigations menu
	 * The function sets the default values for Labels for Login, logout & Dashboard nav
	 * and redirect locations on their clicks
	 * Author: Jeetendra
	 */

	private static function  ntzcrmDefaultNavArgs() {
		$args = array(
			'login_text' => __('Login'),
			'logout_text' => __('Logout'),
			'publication_text' => __('Dashboard'),
			'login_redirect_to' => (get_option('ntzcrm_login_url') != false & strlen(get_option('ntzcrm_login_url')) > 0 )? get_option('ntzcrm_login_url'): site_url("/crm-memberships-login"),
			'logout_redirect_to' =>(get_option('ntzcrm_logout_redirect_url') != false & strlen(get_option('ntzcrm_logout_redirect_url')) > 0 )? get_option('ntzcrm_logout_redirect_url'): site_url("/crm-memberships-login"),
			'publication_redirect_to' => (get_option('ntzcrm_log_redirect_url') != false & strlen(get_option('ntzcrm_log_redirect_url')) > 0 )? get_option('ntzcrm_log_redirect_url'): site_url("/crm-memberships-publications")
		);
		return $args;
	}



    /*
	 * @Function: ntzcrmNavMenuItems
	 * The Function Handles Members Login, Logout and Dashboard access Control
	 * If also tracks if the user is logged in accordingly changes the Lables and redirect urls
	 * for this it takes help of ntzcrmDefaultNavArgs function 
	 * Author: Jeetendra
	 */
    public static function ntzcrmNavMenuItems($items) {
		$instance = wp_parse_args(
			(array)	self::ntzcrmDefaultNavArgs()
		);
		$login_text = trim($instance['login_text']);
		$logout_text = trim($instance['logout_text']);
		$publication_text = trim($instance['publication_text']);
		$login_redirect_to = strip_tags($instance['login_redirect_to']);
		$logout_redirect_to = strip_tags($instance['logout_redirect_to']);
		$publication_redirect_to = strip_tags($instance['publication_redirect_to']);
  
		if( empty( $login_redirect_to ) ){
			$login_redirect_to = site_url();;
		}
		if( empty( $logout_redirect_to ) ){
			$logout_redirect_to = site_url();;
		}
		
		if ( is_user_logged_in() ) {
			$ntzcrm_nav_link = '<li class="ntzcrm-navlink"><a href="' . esc_url(  $publication_redirect_to  ) . '">' . $publication_text . '</a></li><li class="ntzcrm-navlink"><a href="' . esc_url( wp_logout_url( $logout_redirect_to ) ) . '">' . $logout_text . '</a></li>';
		}else {
			$ntzcrm_nav_link = '<li class="ntzcrm-navlink"><a href="' . esc_url( $login_redirect_to ) . '">' . $login_text . '</a></li>';
	    }
		
		// add the ntzcrm menu links to the end of the menu
		$items = $items . $ntzcrm_nav_link;
		return $items;
	} 

	public static function ntzcrmShortcode($atts) {
		extract( shortcode_atts( array(
			'post_id' => 0,
			'user_id' => '',
			'target' => 'same',
			'link' => 'true',
			'link_class' => '',
			'img_class' => '',
			'hide_disable' => false,
			'width' => false,
			'height' => false,
			'text' => '',
			'request' => 'encrypt',
			'context' => 'local'
		), $atts ) );
		if ($post_id <= 0) {
			return '';
		}
		$width_html = '';
		if($width){
			$width_html = ' width="' . $width . '"';
		}
		$height_html = '';
		if($height) {
			$height_html = ' height="' . $height . '"';
		}
		$link=true;
		$userId=$img_url = '';
		
		$link_target = '_self'; 
		$isLoginRequired=get_post_meta($post_id,"is_ntzcrm_login_required",true);
		$accessIcon=(get_post_meta($post_id,"ntzcrm_access_icon",true))?get_post_meta($post_id,"ntzcrm_access_icon",true):"";
		$noAccessIcon=(get_post_meta($post_id,"ntzcrm_noaccess_icon",true))?get_post_meta($post_id,"ntzcrm_noaccess_icon",true):"";
		$postTitle=get_the_title($post_id); 

		if (is_user_logged_in()) { //&&current_user_can('administrator')
			$userId=get_current_user_id();  
			$isAllAccess=get_user_meta($userId,'all_access',true);
			if(!empty($isAllAccess)&&$isAllAccess=="yes"){
				$isLoginRequired="no";
			}	
		}
		  
		$img_url=(!empty($accessIcon))?$accessIcon:NTZCRM_PLUGIN_URL."images/pub-access-enabled.png";
		if(!empty($isLoginRequired)&&$isLoginRequired=="yes"){
			$link=false;
			$img_url=(!empty($noAccessIcon))?$noAccessIcon:NTZCRM_PLUGIN_URL."images/pub-access-disabled.png";  
			$postTags=ntzcrm_dbquery::_getPostTagList($post_id);  
		 	if(!empty($postTags)){ 
				$userTags=ntzcrm_dbquery::_getUserTagList($userId);  
				$matched_result=array_intersect($postTags,$userTags); 
				if(!empty($matched_result)){
					$img_url=(!empty($accessIcon))?$accessIcon:NTZCRM_PLUGIN_URL."images/pub-access-enabled.png";
					$link=true;
				} 
			}
		}
		  
		$content_html = '';
		$text = esc_attr($text); 
		if ($img_url) {
			$content_html = '<div class="ntzcrm-img-icon"><img src="' . esc_attr($img_url) . '" alt="' . $text . '" class="ntzcrm-icon-img ' . $img_class . '" ' . $width_html . $height_html . '/></div>';
		} elseif ($text) {
			$content_html = $text;
		} 
		if($link) {
			return '<a href="' . esc_attr(get_permalink($post_id)) . '" target="' . $link_target . '" class="ntzcrm-icon-link ' . $link_class . '">' . $content_html.'<div class="ntzcrm-pub-lable text-center">'.$postTitle.'</div></a>';
		}elseif (!$link) {
			return "<div class='ntzcrm-icon-link'><div class='ntzcrm-icon'>".$content_html.'<div class="ntzcrm-pub-lable text-center">'.$postTitle.'</div></div></div>';
		} 
		return '<a href="' . esc_attr($link) . '" target="' . $link_target . '" class="ntzcrm-icon-link ' . $link_class . '">' .'<div class="ntzcrm-pub-lable text-center">'.$postTitle.'</div></a>';
	} 

	/* Include css and Js*/
	public static function ntzcrm_include_fronted_css() { 
		wp_enqueue_style('ntzcrm_custom-style', NTZCRM_PLUGIN_URL.'css/ntzcrm_custom.css','1.0.0','all'); 
		//wp_enqueue_style('ntzcrm_bootstrap', NTZCRM_PLUGIN_URL.'css/bootstrap.min.css','4.5.0','all'); 
	}
	public static function ntzcrm_include_css() { 
	    $enablePlugin=get_option('is_actived_ntzcrm');
	    if($enablePlugin=='1'&&is_admin()){
			wp_enqueue_style('select2-style', NTZCRM_PLUGIN_URL.'css/select2/select2.min.css','1.0.0','all');   
	    }
	}
	
	public static function ntzcrm_include_js() { 
	    $enablePlugin=get_option('is_actived_ntzcrm');  
	    if($enablePlugin=='1'&&is_admin()){
		 wp_enqueue_script('select2-script-js', NTZCRM_PLUGIN_URL.'js/select2/select2.full.min.js',array('jquery'),"1.01");  
		 wp_enqueue_script('ntzcrm-admin-custom-js', NTZCRM_PLUGIN_URL.'js/ntzcrm_custom.js',array('jquery'),'1.1');
		}
		
	}
	
	public static function ntzcrm_front_include_js() { 
		$enablePlugin=get_option('is_actived_ntzcrm'); 
		if($enablePlugin=='1'&&!is_admin()){ 
			$logoutRedirectUrl=(!empty(get_option('ntzcrm_logout_redirect_url')))?get_option('ntzcrm_logout_redirect_url'):site_url("/crm-memberships-login"); 
			echo "<script type='text/javascript'> 
	        		var logouturl='".str_replace("&amp;","&",wp_logout_url($logoutRedirectUrl)) ."';
	        </script>";
			wp_enqueue_script('ntzcrm-custom-js', NTZCRM_PLUGIN_URL.'js/ntzcrm_front_custom.js',array('jquery'),'1.0');  
		}  
	}
	
 	public static function _checkPermission() { 
		//  global $post;
		$post_id = get_queried_object_id(); 
 		// $page_object = get_queried_object();
		$isLoginRequired=get_post_meta($post_id,"is_ntzcrm_login_required",true);
		if (is_user_logged_in()) { //&&current_user_can('administrator')
			$userId=get_current_user_id();  
			$isAllAccess=get_user_meta($userId,'all_access',true);
			if(!empty($isAllAccess)&&$isAllAccess=="yes"){
				$isLoginRequired="no";
			}
			ntzcrm_dbquery::_svUserActivities($userId,$post_id);
		}    

		if(!empty($isLoginRequired)&&$isLoginRequired=="yes"){ 
			if (!is_user_logged_in() ) { 
				$loginUrl=(!empty( get_option('ntzcrm_login_url')))?trim(get_option('ntzcrm_login_url')):site_url("/crm-memberships-login"); 
				wp_safe_redirect($loginUrl);
				exit();
			}else {

				$postTags=ntzcrm_dbquery::_getPostTagList($post_id);       
			    $userId=get_current_user_id();
			    $isTagSync=get_user_meta($userId,'ntzcrm_user_tag_sync',true);
				if(empty($isTagSync) || $isTagSync!="yes"){ 
					$getData=get_user_meta($userId,'_ntzcrm_user_tag_ids',true); 
			        if(!empty($getData['ids'])){
			          	ntzcrm_dbquery::_insertUserAccessTag($userId,$getData['ids']); 
			          	if(!empty($isTagSync)){
			          		update_user_meta($userId,'ntzcrm_user_tag_sync',"yes");
			          	}else{
			          		add_user_meta($userId,'ntzcrm_user_tag_sync',"yes");
			          	} 
		            	$body="$userId: This user id is synced. : tags : ".json_encode($getData['ids']);
		            	self::ntzcrmUserSyncRequestLog($body); 
			        }else{
			        	if(!empty($isTagSync)){
			          		update_user_meta($userId,'ntzcrm_user_tag_sync',"no");
			          	}else{
			          		add_user_meta($userId,'ntzcrm_user_tag_sync',"no");
			          	} 
			        }
		    	}
				if(!empty($postTags)&&!is_front_page()){ 
					$userTags=ntzcrm_dbquery::_getUserTagList($userId);  
					$matched_result=array_intersect($postTags,$userTags); 
					if(empty($matched_result)){ 
						wp_safe_redirect(site_url('/',"302"));
						exit();
					} 
				}
			} 
		}
	}  
	public static function createJson($status,$message,$data=""){
		$data = array('status' => $status, 'message' =>$message, 'data' =>$data);
        echo json_encode($data);
        exit();
	}

	public static function sfNtzCrmMembershipRequestLog($body,$filename="request_log.txt"){
		$error_log_enable=get_option('ntzcrm_enable_log'); 
	  
		if($error_log_enable =="yes"){
		  $request=self::ntzcrmRequests();
		  $action=(isset($request['action']))?$request['action']:'';
		  $error_message = " "; 
		  $error_message .= "Action : ".$action." - ".$body;
		  $error_message .= "\n"; 
		  $log_file = NTZCRM_DIR_PATH . "logs/$filename";
		  ini_set("log_errors", FALSE);  
		  ini_set('error_log', $log_file); 
		  error_log($error_message); 
		}
		return true;
	}

	public static function ntzcrmUserSyncRequestLog($body){
		$error_log_enable=get_option('ntzcrm_enable_log');  
		if($error_log_enable =="yes"){ 
		  $error_message = " "; 
		  $error_message .= $body;
		  $error_message .= "\n"; 
		  $log_file = NTZCRM_DIR_PATH . "logs/user_sync_log.txt";
		  ini_set("log_errors", FALSE);  
		  ini_set('error_log', $log_file); 
		  error_log($error_message); 
		}
		return true;
	}
	  
	public static function sfNtzCrmMembershipErrorRequestLog($msg="",$body=""){
		$error_log_enable=get_option('ntzcrm_enable_log');
		if($error_log_enable =="yes"){
			$request=self::ntzcrmRequests();
			$action=(isset($request['action']))?$request['action']:'';
			$error_message = " "; 
			$error_message .= "Action : ".$action." - ".json_encode($body).' : '.$msg;
			$error_message .= "\n"; 
			$log_file = NTZCRM_DIR_PATH . "log/ntzcrm_errorlog.txt";
			ini_set("log_errors", FALSE);  
			ini_set('error_log', $log_file); 
			error_log($error_message); 
		}
		return true;
	}
	
	/**/
	public static function ntzcrmCheckToken($api_token='',$key=''){
		$pass=get_option('ntzcrm_api_token');
		$savkey=get_option('ntzcrm_api_key');
		if(!empty($key)&&!empty($api_token)&&$pass==$api_token&&$key==$savkey){
			return true;
		}
		return false;
	} 

	public static function ntzcrmLogin(){    
		ob_start();
		include(NTZCRM_DIR_PATH."includes/view/login.php");
		$fileValue = ob_get_contents();
		ob_end_clean();  
		return $fileValue;
	}  

	public static function ntzcrmPublications($attr=""){
		ob_start();
		$results=ntzcrm_dbquery::_getFrontPublications($attr);
		 
		include(NTZCRM_DIR_PATH."includes/view/ntzcrm-publications.php");
		
		$fileValue = ob_get_contents();
		ob_end_clean();  
		return $fileValue;
	}

	public static function ntzcrmRequests($cbArray=array()){
		$request=array(); 
		if(!empty($_REQUEST)){
			foreach($_REQUEST as $fieldKey =>$val) {
				if(!empty($cbArray)&&in_array($fieldKey,$cbArray)){
					$request[$fieldKey] =array_map( 'sanitize_text_field', $val);
				}else{ 
					if($fieldKey=="email"){
						$request[$fieldKey]=sanitize_email($val);
					}elseif(in_array($fieldKey,array("tag_ids","usertag","posttag","pubid"))){
						$parsedArr=wp_parse_id_list($val);
						$request[$fieldKey] =array_map( 'sanitize_text_field', $parsedArr);
					}else{
						$request[$fieldKey]=sanitize_text_field($val);
					}
				}
			}			 
		}  
		return $request; 
	}

	public static function ntzcrmJsonRequests($cbArray=array()){
		$request=array(); 
		header("Content-type: application/json");
		$body = file_get_contents('php://input'); 
		$request = (array)json_decode($body);
		if(!empty($request)){
			 
			self::sfNtzCrmMembershipRequestLog($body); 
			foreach($request as $fieldKey =>$val) {
				if(!empty($cbArray)&&in_array($fieldKey,$cbArray)){
					$request[$fieldKey] =array_map( 'sanitize_text_field', $val);
				}else{ 
					if($fieldKey=="data"){  // Use for multi array.
						foreach($request["data"] as $mulitKey =>$dataVal) {
							$request[$fieldKey][$mulitKey]=self::_ntzcrmMultiArrSanitize($dataVal); 
						} 
					}else{
						if($fieldKey=="person_email" || $fieldKey=="email"){
							$request[$fieldKey]=sanitize_email($val);
						}elseif(in_array($fieldKey,array("tag_ids","usertag","posttag","pubid"))){
							$parsedArr=wp_parse_id_list($val);
							$request[$fieldKey] =($val!='all')?array_map( 'sanitize_text_field',$parsedArr):'all'; 
							  
							
						}else{
							$request[$fieldKey]=sanitize_text_field($val);
						}
					}
				}
			}			 
		}  
		return $request; 
	}

	public static function _ntzcrmMultiArrSanitize($dataVal){ 
		$request=array();
		$dataVal=(array)$dataVal;
		foreach($dataVal as $mulitKey =>$val) {
			if($mulitKey=="person_email" || $mulitKey=="email"){
				$request[$mulitKey]=sanitize_email($val);
			}elseif(in_array($mulitKey,array("tag_ids","usertag","posttag","pubid"))){
				$request[$mulitKey] ==($val!='all')?array_map( 'sanitize_text_field',wp_parse_id_list($val)):'all'; 
			}else{
				$request[$mulitKey]=sanitize_text_field($val);
			}
		}
		return $request;	
	}

}
